@@ -14,14 +14,12 @@ from tg import (
         expose,
         flash,
         redirect,
-        validate,
         )
 from tg.decorators import (
         with_trailing_slash,
         without_trailing_slash,
         )
 
-from allura.controllers import BaseController
 from allura.lib.decorators import require_post
 from allura.lib import helpers as h
 from allura.model import ApiTicket, AuditLog
@@ -29,25 +27,20 @@ from allura.model import ApiTicket, AuditLog
 from forgeimporters.base import (
         ToolImporter,
         ToolImportForm,
+        ToolImportController,
         )
 
 from tracwikiimporter.scripts.wiki_from_trac.extractors import WikiExporter
 from tracwikiimporter.scripts.wiki_from_trac.loaders import load_data
 from tracwikiimporter.scripts.wiki_from_trac.wiki_from_trac import WikiFromTrac
-from forgewiki.wiki_main import ForgeWikiApp
 
 
 class TracWikiImportForm(ToolImportForm):
     trac_url = fev.URL(not_empty=True)
 
 
-class TracWikiImportController(BaseController):
-    def __init__(self):
-        self.importer = TracWikiImporter()
-
-    @property
-    def target_app(self):
-        return self.importer.target_app
+class TracWikiImportController(ToolImportController):
+    import_form = TracWikiImportForm
 
     @with_trailing_slash
     @expose('jinja:tracwikiimporter:templates/index.html')
@@ -58,7 +51,6 @@ class TracWikiImportController(BaseController):
     @without_trailing_slash
     @expose()
     @require_post()
-    @validate(TracWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, trac_url, mount_point, mount_label, **kw):
         if self.importer.enforce_limit(c.project):
             self.importer.post(
@@ -74,7 +66,7 @@ class TracWikiImportController(BaseController):
 
 
 class TracWikiImporter(ToolImporter):
-    target_app = ForgeWikiApp
+    target_app_ep_names = 'wiki'
     source = 'Trac'
     controller = TracWikiImportController
     tool_label = 'Wiki'
