@@ -92,7 +92,8 @@ class TestTracWikiImportController(TestController, TestCase):
         """Mount Trac import controller on the Wiki admin controller"""
         super(self.__class__, self).setUp()
         from forgewiki.wiki_main import WikiAdminController
-        WikiAdminController._importer = TracWikiImportController()
+        WikiAdminController._importer = \
+                TracWikiImportController(TracWikiImporter())
 
     @with_wiki
     def test_index(self):
